"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const events_1 = require("events");
const log4js_1 = require("log4js");
const CodeReaderIpcClient_1 = require("./CodeReaderIpcClient");
const logger = log4js_1.getLogger('CodeReader');
const CODE_LENGTH = 10;
const DELAY_BETWEEN_SCANS = 1000;
class CodeReader {
    constructor(readerName) {
        logger.info(`CodeReader '${readerName}' created`);
        this.readerName = readerName;
        this.lastScan = new Date(2000, 0, 1);
        this.events = new events_1.EventEmitter();
    }
    start() {
        if (this.ipcClient !== undefined) {
            return;
        }
        this.enabled = true;
        this.ipcClient = new CodeReaderIpcClient_1.CodeReaderIpcClient(this.readerName);
        this.ipcClient.start();
        this.ipcClient.on('data', data => this.events.emit('data', data));
        this.ipcClient.on('error', e => {
            logger.error(e);
            this.events.emit('error', e);
        });
        logger.info(`CodeReader '${this.readerName}' started`);
    }
    stop() {
        // this.ipcClient.off('data', data => this.events.emit('data', data));
        // this.ipcClient.off('error', e => {
        //   logger.error(e);
        //   this.events.emit('error', e);
        // });
        this.ipcClient.stop();
        this.ipcClient = undefined;
        this.enabled = false;
        logger.info(`CodeReader '${this.readerName}' stopped`);
    }
    on(event, listener) {
        this.events.on(event, listener);
        // this.events.on(event, listener);
    }
    off(event, listener) {
        this.events.off(event, listener);
    }
    onCode(code) {
        if (this.enabled === false) {
            return;
        }
        // Check each character for numeric
        const isNumeric = /^\d+$/.test(code);
        if (!isNumeric) {
            return;
        }
        // Check code length
        if (code.length !== CODE_LENGTH) {
            return;
        }
        // Check delay between scans
        const nowDate = new Date();
        const diff = nowDate.getTime() - this.lastScan.getTime();
        if (diff > DELAY_BETWEEN_SCANS) {
            this.lastScan = nowDate;
            this.ipcClient.send(code);
        }
    }
}
exports.CodeReader = CodeReader;

//# sourceMappingURL=CodeReader.js.map
