"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const dotup_ts_node_ipc_1 = require("dotup-ts-node-ipc");
const log4js_1 = require("log4js");
const CHANNEL_NAME = 'DOTUP-IPC-SERVER';
const logger = log4js_1.getLogger('CodeReader');
class CodeReaderIpcClient {
    constructor(name) {
        logger.info(`Creating CodeReaderIpcClient (${name})`);
        this.name = name;
    }
    start() {
        if (this.client !== undefined) {
            return;
        }
        logger.info(`Starting CodeReaderIpcClient (${this.name})`);
        this.client = new dotup_ts_node_ipc_1.IpcClient(CHANNEL_NAME, `client ${this.name}`);
        this.client.on('data', data => {
            logger.debug(`${this.name}- ${data}`);
        });
        this.client.on('error', e => {
            logger.error(e);
            // console.error(`${this.name}- ${e}`);
        });
        this.client.start();
    }
    send(data) {
        if (this.client === undefined) {
            return;
        }
        this.client.send(data);
    }
    // tslint:disable-next-line: no-any
    on(event, listener) {
        switch (event) {
            case 'data':
                this.client.on('data', listener);
                return this;
            case 'error':
                this.client.on('error', listener);
                return this;
        }
    }
    // tslint:disable-next-line: no-any
    off(event, listener) {
        this.client.off(event, listener);
        return this;
    }
    stop() {
        if (this.client !== undefined) {
            logger.info(`Stopping CodeReaderIpcClient (${this.name})`);
            this.client.stop();
            this.client.removeAllListeners();
            this.client = undefined;
        }
    }
}
exports.CodeReaderIpcClient = CodeReaderIpcClient;

//# sourceMappingURL=CodeReaderIpcClient.js.map
